#line 2 "lexer.c"

#line 4 "lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 117
#define YY_END_OF_BUFFER 118
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[407] =
    {   0,
        0,    0,    0,    0,  118,  116,    6,    7,  116,   18,
      116,  116,  116,  116,  116,  116,  116,   16,   15,  116,
      116,  116,  115,  115,  115,  115,  116,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  116,  116,    2,  117,    1,
        2,   96,   86,   94,   88,    0,    0,   85,   81,   87,
       82,   84,   83,   16,    0,   15,  100,   97,   95,   98,
       99,  115,  115,  105,  115,  115,  115,   90,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,   49,  115,  115,  115,  115,  115,  115,  115,

      115,  115,  115,  115,  115,  115,  115,  115,  115,   89,
       93,   10,    0,    9,    5,    5,    5,   11,    0,   11,
        0,    0,   17,   91,   92,  101,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,   47,  115,  115,
       51,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,    8,    9,
        0,    0,   14,    0,    0,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,   38,  115,   40,   41,   42,  115,

       45,  115,  115,  115,  115,  115,  115,   37,   52,  115,
      115,  115,  115,  115,  115,  115,  115,   64,  115,  115,
      115,  115,  115,  115,  115,  115,   75,   50,  115,  115,
        4,    3,    0,    0,  112,  108,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,   21,   22,
      115,   23,  115,  115,  115,  115,  115,  115,   46,  115,
      115,  115,  115,  115,   35,  115,  115,  115,  115,  115,
      115,   79,   59,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
       78,  115,   12,   13,  104,  115,  115,  115,  115,  115,

      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,   44,  115,  115,  115,  115,  115,   48,   36,
      115,  115,  115,  115,   60,   61,   62,   63,   56,   65,
      115,  115,   66,   67,   68,   70,   69,   73,   74,  115,
      115,  115,  115,  102,  115,  114,  106,  103,  109,  111,
      115,   19,   20,  115,   25,   24,  115,   39,   43,   30,
      115,  115,   32,  115,  115,   55,  115,  115,  115,   71,
      115,  115,  115,   80,  110,  115,  113,  115,  115,  115,
       29,   31,   33,   34,   53,  115,   58,  115,  115,   76,
      115,  107,  115,  115,  115,   54,  115,   72,   77,  115,

       27,  115,   57,   26,   28,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    1,    7,    8,    9,    1,
        1,   10,   11,    1,   12,    1,   13,   14,   15,   15,
       15,   15,   15,   15,   15,   16,   16,    1,    1,   17,
       18,   19,    1,    1,   20,   21,   22,   23,   24,   25,
       26,   27,   28,   29,   30,   31,   29,   32,   33,   34,
       29,   35,   36,   37,   38,   29,   39,   40,   29,   29,
        1,   41,    1,   42,   43,    1,   44,   45,   46,   47,

       48,   49,   50,   51,   52,   29,   53,   54,   55,   56,
       57,   58,   29,   59,   60,   61,   62,   63,   64,   65,
       66,   67,    1,   68,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[69] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    3,    1,
        1,    1,    1,    4,    4,    4,    1,    1,    1,    4,
        4,    4,    4,    4,    4,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        1,    1,    5,    4,    4,    4,    4,    4,    4,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    1
    } ;

static yyconst flex_int16_t yy_base[418] =
    {   0,
        0,  465,   66,   67,  470,  472,  472,  472,  451,  472,
      450,   65,  426,  448,   63,   64,  447,   63,   70,   62,
      446,   69,    0,   66,  420,  419,  443,   30,  401,   42,
       48,   46,  411,   56,  406,  413,  408,  401,   33,  406,
       54,  394,  395,  400,  393,   57,  107,  472,  472,  472,
       86,  472,  472,  472,  472,  440,  115,  472,  472,  472,
      472,  472,  472,  103,    0,  117,  430,  472,  472,  472,
      429,    0,  421,    0,  114,  113,  417,  472,  394,  397,
      394,   94,  394,  384,  388,   88,  394,   92,  389,  377,
      376,  373,    0,  372,  372,  378,  366,  382,  376,  366,

       82,  359,  102,  380,  364,  371,  370,  369,  358,  472,
      472,  472,  144,    0,  472,  138,    0,  472,  410,  409,
      140,  408,    0,  472,  472,    0,  385,  387,  386,  375,
      385,  378,  132,  111,  358,  365,  352,  355,  112,  345,
      348,  349,  355,  348,  355,  104,  339,    0,  347,  131,
        0,  337,  349,  348,  347,  338,  345,  340,  329,  342,
      328,  132,  328,  326,  331,  338,  330,  327,  472,    0,
      154,    0,  472,  161,    0,  351,  346,  349,  358,  354,
      355,  336,  160,  351,  339,  325,  328,  319,  317,  319,
      309,  319,  322,  313,    0,  316,    0,    0,  301,  301,

        0,  301,  304,  140,  308,  302,  305,    0,   65,  302,
      296,  295,  292,  296,  284,  291,  292,    0,  297,  140,
      291,  142,  289,  287,  283,  295,  142,    0,  294,  291,
      472,  472,  331,  330,    0,    0,  314,  314,  314,  308,
      310,  306,  304,  307,  310,  301,  284,  275,    0,    0,
      278,    0,  281,  272,  267,  266,  260,  260,    0,  258,
      274,  269,  251,  271,    0,  251,  266,  260,  263,  254,
      257,    0,    0,  259,  244,  258,  249,  255,  244,  246,
      242,  250,  243,  239,  244,  237,  236,  239,  245,  240,
        0,  243,  472,  472,    0,  262,  259,  264,  265,  251,

      250,  258,  260,  245,  234,  226,  236,  231,  223,  214,
      214,  226,    0,  224,  212,  206,  209,  208,    0,    0,
      212,  211,  214,  205,    0,    0,    0,    0,  210,    0,
      216,  207,    0,    0,    0,    0,    0,    0,    0,  212,
      210,  200,  223,    0,  235,    0,    0,    0,    0,    0,
      232,    0,    0,  154,    0,    0,  207,    0,    0,    0,
      206,  192,    0,  201,  204,    0,  193,  188,  196,    0,
      203,  185,  194,    0,    0,  214,    0,  199,  177,  192,
        0,    0,    0,    0,    0,  175,    0,  166,  158,    0,
      150,    0,  150,  148,  147,    0,  146,    0,    0,  157,

        0,  153,    0,    0,    0,  472,  212,  217,  219,  224,
      229,  199,  234,  196,  237,  166,  162
    } ;

static yyconst flex_int16_t yy_def[418] =
    {   0,
      406,    1,  407,  407,  406,  406,  406,  406,  406,  406,
      406,  406,  408,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  409,  409,  409,  409,  406,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  406,  406,  406,  406,  406,
      410,  406,  406,  406,  406,  406,  411,  406,  406,  406,
      406,  406,  406,  406,  412,  406,  406,  406,  406,  406,
      406,  409,  409,  409,  409,  409,  409,  406,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,

      409,  409,  409,  409,  409,  409,  409,  409,  409,  406,
      406,  406,  406,  413,  406,  406,  414,  406,  406,  406,
      406,  415,  412,  406,  406,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  406,  413,
      406,  416,  406,  406,  417,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,

      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      406,  406,  406,  406,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  406,  406,  409,  409,  409,  409,  409,  409,

      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,

      409,  409,  409,  409,  409,    0,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406
    } ;

static yyconst flex_int16_t yy_nxt[541] =
    {   0,
        6,    7,    8,    9,   10,    6,   11,   12,   13,   14,
       15,   16,   17,   18,   19,   19,   20,   21,   22,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   24,   25,   23,   26,   23,   23,   23,   23,
        6,   27,   23,   28,   29,   30,   23,   31,   32,   33,
       23,   34,   23,   35,   36,   37,   38,   39,   40,   41,
       42,   23,   43,   44,   23,   45,   23,   46,   49,   49,
       50,   50,   54,   59,  110,   61,   64,   64,   67,   68,
       60,   62,   55,   66,   66,   66,   70,   71,   79,   80,
       73,   99,   82,   85,  100,   89,   83,   74,   84,  116,

      116,   86,   90,   91,   93,  102,   51,   51,   75,  112,
       87,   94,   88,  268,  103,  104,   64,   64,  269,  105,
      113,  113,  113,  120,  111,  114,  270,   65,  121,  121,
       66,   66,   66,  127,  131,  142,  128,  137,  129,  145,
      138,  158,  159,  146,  132,  161,  169,  143,  173,  130,
      117,  171,  171,  174,  174,  182,  183,  113,  113,  113,
      162,  186,  192,  200,  201,  234,  184,  231,  231,  232,
      185,  187,  193,  204,  233,  233,  205,  219,  206,  122,
      220,  242,  243,  221,  261,  222,  262,  263,  207,  283,
      208,  280,  223,  224,  244,  289,  281,  264,  378,  172,

      290,  379,  123,  405,  404,  284,  403,  402,  401,  400,
      399,  380,   48,   48,   48,   48,   48,   56,  398,   56,
       56,   56,   72,   72,  115,  397,  115,  115,  115,  119,
      396,  119,  119,  119,  170,  395,  170,  170,  170,  175,
      175,  394,  393,  392,  391,  390,  389,  388,  387,  386,
      385,  384,  383,  382,  381,  377,  376,  375,  374,  373,
      372,  371,  370,  369,  368,  367,  366,  365,  364,  363,
      362,  361,  360,  359,  358,  357,  356,  355,  354,  353,
      352,  351,  350,  349,  348,  347,  346,  345,  344,  343,
      342,  341,  340,  339,  338,  337,  336,  335,  334,  333,

      332,  331,  330,  329,  328,  327,  326,  325,  324,  323,
      322,  321,  320,  319,  318,  317,  316,  315,  314,  313,
      312,  311,  310,  309,  308,  307,  306,  305,  304,  303,
      302,  301,  300,  299,  298,  297,  296,  295,  294,  293,
      292,  291,  288,  287,  286,  285,  282,  279,  278,  277,
      276,  275,  274,  273,  272,  271,  267,  266,  265,  260,
      259,  258,  257,  256,  255,  254,  253,  252,  251,  250,
      249,  248,  247,  246,  245,  241,  240,  239,  238,  237,
      236,  235,  230,  229,  228,  227,  226,  225,  218,  217,
      216,  215,  214,  213,  212,  211,  210,  209,  203,  202,

      199,  198,  197,  196,  195,  194,  191,  190,  189,  188,
      181,  180,  179,  178,  177,  176,  173,  173,  173,  168,
      167,  166,  165,  164,  163,  160,  157,  156,  155,  154,
      153,  152,  151,  150,  149,  148,  147,  144,  141,  140,
      139,  136,  135,  134,  133,  126,  125,  124,  118,  109,
      108,  107,  106,  101,   98,   97,   96,   95,   92,   81,
       78,   77,   76,   69,   63,   58,   57,   53,   52,  406,
       47,    5,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,

      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406
    } ;

static yyconst flex_int16_t yy_chk[541] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    4,
        3,    4,   12,   15,   46,   16,   18,   18,   20,   20,
       15,   16,   12,   19,   19,   19,   22,   22,   28,   28,
       24,   39,   30,   31,   39,   32,   30,   24,   30,   51,

       51,   31,   32,   32,   34,   41,    3,    4,   24,   47,
       31,   34,   31,  209,   41,   41,   64,   64,  209,   41,
       47,   47,   47,   57,   46,   47,  209,   18,   57,   57,
       66,   66,   66,   75,   76,   86,   75,   82,   75,   88,
       82,  101,  101,   88,   76,  103,  113,   86,  121,   75,
       51,  116,  116,  121,  121,  133,  133,  113,  113,  113,
      103,  134,  139,  146,  146,  417,  133,  171,  171,  416,
      133,  134,  139,  150,  174,  174,  150,  162,  150,   57,
      162,  183,  183,  162,  204,  162,  204,  204,  150,  222,
      150,  220,  162,  162,  183,  227,  220,  204,  354,  414,

      227,  354,  412,  402,  400,  222,  397,  395,  394,  393,
      391,  354,  407,  407,  407,  407,  407,  408,  389,  408,
      408,  408,  409,  409,  410,  388,  410,  410,  410,  411,
      386,  411,  411,  411,  413,  380,  413,  413,  413,  415,
      415,  379,  378,  376,  373,  372,  371,  369,  368,  367,
      365,  364,  362,  361,  357,  351,  345,  343,  342,  341,
      340,  332,  331,  329,  324,  323,  322,  321,  318,  317,
      316,  315,  314,  312,  311,  310,  309,  308,  307,  306,
      305,  304,  303,  302,  301,  300,  299,  298,  297,  296,
      292,  290,  289,  288,  287,  286,  285,  284,  283,  282,

      281,  280,  279,  278,  277,  276,  275,  274,  271,  270,
      269,  268,  267,  266,  264,  263,  262,  261,  260,  258,
      257,  256,  255,  254,  253,  251,  248,  247,  246,  245,
      244,  243,  242,  241,  240,  239,  238,  237,  234,  233,
      230,  229,  226,  225,  224,  223,  221,  219,  217,  216,
      215,  214,  213,  212,  211,  210,  207,  206,  205,  203,
      202,  200,  199,  196,  194,  193,  192,  191,  190,  189,
      188,  187,  186,  185,  184,  182,  181,  180,  179,  178,
      177,  176,  168,  167,  166,  165,  164,  163,  161,  160,
      159,  158,  157,  156,  155,  154,  153,  152,  149,  147,

      145,  144,  143,  142,  141,  140,  138,  137,  136,  135,
      132,  131,  130,  129,  128,  127,  122,  120,  119,  109,
      108,  107,  106,  105,  104,  102,  100,   99,   98,   97,
       96,   95,   94,   92,   91,   90,   89,   87,   85,   84,
       83,   81,   80,   79,   77,   73,   71,   67,   56,   45,
       44,   43,   42,   40,   38,   37,   36,   35,   33,   29,
       27,   26,   25,   21,   17,   14,   13,   11,    9,    5,
        2,  406,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,

      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406,
      406,  406,  406,  406,  406,  406,  406,  406,  406,  406
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lexer"
#line 2 "lexer"

#include "scanner.ih"
#define YY_NO_INPUT


#line 720 "lexer.c"

#define INITIAL 0
#define str 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 12 "lexer"


#line 941 "lexer.c"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 407 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 472 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 14 "lexer"
{
                            /* having read a "string", unescape it 
                               the returned string does not have surrounding
                               double quotes */
                            BEGIN 0;
                            return STRING;
                        }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 21 "lexer"
{
                            util_catString(yytext);
                        }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 25 "lexer"
{
                            util_catString(sc_scan("%x", yytext + 2));
                        }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 29 "lexer"
{
                            util_catString(sc_scan("%o", yytext + 1));
                        }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 33 "lexer"
{  
                            util_catString(sc_escapedChar(yytext[1]));
                        }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 37 "lexer"
;
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 38 "lexer"
++yylineno;
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 39 "lexer"
{
                            sc_setLineNr();
                        }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 42 "lexer"
{
                            sc_changeFile(yytext + 2);
                        }
	YY_BREAK
case 10:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 45 "lexer"
{
                            sc_popFile();
                        }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 48 "lexer"
{
                            sc_charConst();
                            return STRING;
                        }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 53 "lexer"
{
                            util_setString(sc_scan("%o", yytext + 2));
                            return STRING;
                        }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 58 "lexer"
{
                            util_setString(sc_scan("%x", yytext + 3));
                            return STRING;
                        }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 63 "lexer"
{
                            util_setString(sc_escapedChar(yytext[2]));
                            return STRING;
                        }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 68 "lexer"
{
                            util_scan("%u", yytext);
                            return NUMBER;
                        }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 72 "lexer"
{
                            util_scan("%o", yytext);
                            return NUMBER;
                        }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 76 "lexer"
{
                            util_scan("%x", yytext + 2);
                            return NUMBER;
                        }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 81 "lexer"
{
                            util_setString(""); 
                            BEGIN str;
                        }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 86 "lexer"
{
                            yylval.type = f_arg_head;
                            return ARG_HEAD;
                        }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 90 "lexer"
{
                            yylval.type = f_arg_tail;
                            return ARG_TAIL;
                        }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 94 "lexer"
{                   /* ascii_int may become ascii_str */
                            yylval.type = f_ascii_int;
                            return ASCII;
                        }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 98 "lexer"
{
                            return BREAK;
                        }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 101 "lexer"
{
                            yylval.type = f_chdir;
                            return CHDIR;
                        }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 105 "lexer"
{
                            yylval.type = f_cmd_tail;
                            return CMD_TAIL;
                        }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 109 "lexer"
{
                            yylval.type = f_cmd_head;
                            return CMD_HEAD;
                        }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 113 "lexer"
{
                            yylval.type = f_c_base;
                            return C_BASE;
                        }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 117 "lexer"
{
                            yylval.type = f_c_ext;
                            return C_EXT;
                        }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 121 "lexer"
{
                            yylval.type = f_c_path;
                            return C_PATH;
                        }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 125 "lexer"
{
                            return CONTINUE;
                        }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 128 "lexer"
{
                            yylval.type = f_fprintf;
                            return FPRINTF;
                        }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 132 "lexer"
{
                            yylval.type = f_g_base;
                            return G_BASE;
                        }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 136 "lexer"
{
                            yylval.type = f_g_ext;
                            return G_EXT;
                        }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 140 "lexer"
{
                            yylval.type = f_g_dext;
                            return G_DEXT;
                        }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 144 "lexer"
{
                            yylval.type = f_g_path;
                            return G_PATH;
                        }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 148 "lexer"
{
                            yylval.type = f_getch;
                            return GETCH;
                        }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 152 "lexer"
{
                            yylval.type = f_getpid;
                            return GETPID;
                        }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 156 "lexer"
{
                            yylval.type = f_gets;
                            return GETS;
                        }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 160 "lexer"
{
                            yylval.type = f_echo;
                            return ECHO_TOKEN;
                        }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 164 "lexer"
{
                            yylval.type = f_element;
                            return ELEMENT;
                        }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 168 "lexer"
{
                            return ELSE;
                        }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 171 "lexer"
{
                            yylval.type = f_eval;
                            return EVAL;
                        }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 175 "lexer"
{
                            yylval.type = f_exec;
                            return EXEC;
                        }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 179 "lexer"
{
                            yylval.type = f_execute;
                            return EXECUTE;
                        }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 183 "lexer"
{
                            yylval.type = f_exists;
                            return EXISTS;
                        }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 187 "lexer"
{
                            yylval.type = op_exit;
                            return EXIT;
                        }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 191 "lexer"
{
                            yylval.type = f_fgets;
                            return FGETS;
                        }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 195 "lexer"
{
                            return FOR;
                        }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 198 "lexer"
{
                            yylval.type = f_getenv;
                            return GETENV;
                        }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 202 "lexer"
{
                            return IF;
                        }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 205 "lexer"
{
                            yylval.type = 0;    /* 0 == void */
                            return VOID;
                        }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 209 "lexer"
{
                            yylval.type = e_int;
                            return INT;
                        }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 213 "lexer"
{
                            yylval.type = e_list;
                            return LIST;
                        }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 217 "lexer"
{
                            yylval.type = f_listfind;
                            return LISTFIND;
                        }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 221 "lexer"
{
                            yylval.type = f_listunion;
                            return LISTUNION;
                        }
	YY_BREAK
case 55:
#line 226 "lexer"
case 56:
#line 227 "lexer"
case 57:
YY_RULE_SETUP
#line 227 "lexer"
{
                            sc_saveInfo();
                            yylval.type = f_listlen;
                            return LISTLEN;
                        }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 232 "lexer"
{
                            yylval.type = f_makelist;
                            return MAKELIST;
                        }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 236 "lexer"
{
                            yylval.type = op_older;
                            return OLDER;
                        }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 240 "lexer"
{
                            yylval.type = f_printf;
                            return PRINTF;
                        }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 244 "lexer"
{
                            yylval.type = f_putenv;
                            return PUTENV;
                        }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 248 "lexer"
{
                            yylval.type = f_resize;
                            return RESIZE;
                        }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 253 "lexer"
{
                            yylval.type = op_ret;
                            return RETURN;
                        }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 257 "lexer"
{
                            yylval.type = f_stat;
                            return STAT;
                        }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 261 "lexer"
{
                            yylval.type = f_strchr;
                            return STRCHR;
                        }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 265 "lexer"
{
                            yylval.type = e_str;
                            return STRINGTYPE;
                        }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 269 "lexer"
{
                            yylval.type = f_strlen;
                            return STRLEN;
                        }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 273 "lexer"
{
                            yylval.type = f_strlwr;
                            return STRLWR;
                        }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 277 "lexer"
{
                            yylval.type = f_strupr;
                            return STRUPR;
                        }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 281 "lexer"
{
                            yylval.type = f_strtok;
                            return FIELDS;
                        }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 285 "lexer"
{
                            yylval.type = f_strfind;
                            return STRFIND;
                        }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 289 "lexer"
{
                            yylval.type = f_strformat;
                            return STRFORMAT;
                        }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 293 "lexer"
{
                            yylval.type = f_substr;
                            return SUBSTR;
                        }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 297 "lexer"
{
                            yylval.type = f_system;
                            return SYSTEM;
                        }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 301 "lexer"
{
                            yylval.type = f_trim;
                            return TRIMLEFT;
                        }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 305 "lexer"
{
                            yylval.type = f_trimleft;
                            return TRIMLEFT;
                        }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 309 "lexer"
{
                            yylval.type = f_trimright;
                            return TRIMRIGHT;
                        }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 313 "lexer"
{
                            return WHILE;
                        }
	YY_BREAK
case 79:
#line 317 "lexer"
case 80:
YY_RULE_SETUP
#line 317 "lexer"
{
                            yylval.type = op_younger;
                            return YOUNGER;
                        }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 321 "lexer"
{
                            return INC;
                        }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 324 "lexer"
{
                            return DEC;
                        }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 327 "lexer"
{
                            return DIV_IS;
                        }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 330 "lexer"
{
                            return MINUS_IS;
                        }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 333 "lexer"
{
                            return MUL_IS;
                        }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 336 "lexer"
{
                            return MOD_IS;
                        }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 339 "lexer"
{
                            return PLUS_IS;
                        }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 342 "lexer"
{
                            return AND_IS;
                        }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 345 "lexer"
{
                            return OR_IS;
                        }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 348 "lexer"
{
                            return XOR_IS;
                        }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 351 "lexer"
{
                            return SHL_IS;
                        }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 354 "lexer"
{
                            return SHR_IS;
                        }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 357 "lexer"
{
                            return OR;
                        }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 360 "lexer"
{
                            return AND;
                        }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 363 "lexer"
{
                            return EQUAL;
                        }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 366 "lexer"
{
                            return NOT_EQUAL;
                        }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 369 "lexer"
{
                            return SMALLER_EQUAL;
                        }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 372 "lexer"
{
                            return GREATER_EQUAL;
                        }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 375 "lexer"
{
                            return SHR;
                        }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 378 "lexer"
{
                            return SHL;
                        }
	YY_BREAK
case 101:
#line 382 "lexer"
case 102:
YY_RULE_SETUP
#line 382 "lexer"
{
                            util_setString("0");
                            return NUMBER;
                        }
	YY_BREAK
case 103:
#line 387 "lexer"
case 104:
#line 388 "lexer"
case 105:
YY_RULE_SETUP
#line 388 "lexer"
{
                            util_setString("1");
                            return NUMBER;
                        }
	YY_BREAK
case 106:
#line 393 "lexer"
case 107:
#line 394 "lexer"
case 108:
YY_RULE_SETUP
#line 394 "lexer"
{
                            util_setString("2");
                            return NUMBER;
                        }
	YY_BREAK
case 109:
#line 399 "lexer"
case 110:
YY_RULE_SETUP
#line 399 "lexer"
{
                            util_setString("4");
                            return NUMBER;
                        }
	YY_BREAK
case 111:
#line 404 "lexer"
case 112:
YY_RULE_SETUP
#line 404 "lexer"
{
                            util_setString("8");
                            return NUMBER;
                        }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 408 "lexer"
{
                            util_setString("16");
                            return NUMBER;
                        }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 412 "lexer"
{
                            util_setString("32");
                            return NUMBER;
                        }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 416 "lexer"
{
                            util_setString(yytext);
                            return IDENTIFIER;
                        }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 420 "lexer"
return yytext[0];
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 421 "lexer"
ECHO;
	YY_BREAK
#line 1839 "lexer.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(str):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 407 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 407 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 406);

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 420 "lexer"
